.. Calcbench API Client documentation master file, created by
   sphinx-quickstart on Thu Jul 11 10:06:22 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Calcbench Python API Client
================================================

.. toctree::
   :maxdepth: 2


   getting-started
   numeric-data
   disclosures
   face-statements
   filings
   companies
   push-notification
   metrics
   raw-numeric-XBRL
   raw-numeric-non-XBRL
   business-combinations
   dimensional
   press-release
   downloaders

Examples
--------

https://github.com/calcbench/notebooks